@@ -218,9 +218,9 @@ class Base(base.NodeTest):
         return {'uuid': self.uuid, 'finished': finished, 'error': error,
                 'state': state, 'finished_at': finished_at,
                 'started_at': started_at,
-                'links': [{u'href': u'%s/v1/introspection/%s' % (self.ROOT_URL,
-                                                                 self.uuid),
-                           u'rel': u'self'}]}
+                'links': [{'href': '%s/v1/introspection/%s' % (self.ROOT_URL,
+                                                               self.uuid),
+                           'rel': 'self'}]}
 
     def check_status(self, status, finished, state, error=None):
         self.assertEqual(
@@ -347,7 +347,7 @@ class Test(Base):
         calls = [
             mock.call(node_uuid=self.uuid, address=self.macs[2],
                       extra={'client-id': self.client_id},
-                      is_pxe_enabled=False),
+                      is_pxe_enabled=True),
         ]
         self.assertFalse(self.cli.patch_port.called)
         self.cli.create_port.assert_has_calls(calls, any_order=True)
